# msions

'A python package for creating MS TIC and ion plots'

## Installation

```bash
$ pip install msions
```

## Usage
`msions` can be used to work with Hardklor and Kronik files and to create MS TIC and ion plots.

```python
import msions.mzml as mzml
import msions.hardklor as hk
import msions.kronik as kro
import msions.percolator as perc
import msions.encyclopedia as encyclo
import msions.msplot as msplot
import msions.utils as msutils
```

See the [documentation](https://msions.readthedocs.io/en/latest/example.html) for examples.

## Contributing

Interested in contributing? Check out the contributing guidelines. Please note that this project is released with a Code of Conduct. By contributing to this project, you agree to abide by its terms.

## License

`msions` was created by Danielle A. Faivre. It is licensed under the terms of the Apache License 2.0 license.

## Credits

`msions` was created with [`cookiecutter`](https://cookiecutter.readthedocs.io/en/latest/) and the `py-pkgs-cookiecutter` [template](https://github.com/py-pkgs/py-pkgs-cookiecutter).
